betty.test_utils.locale.localized - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for betty.test_utils.locale.localized

    """
    Test utilities for :py:mod:`betty.locale.localized`.
    """

    from betty.locale.localized import Localized

    class DummyLocalized(Localized):
        """
        A dummy :py:class:`betty.locale.localized.Localized` implementation.
        """

        def __init__(self, locale: str):
            self._locale = locale